@@ -17,7 +17,7 @@ KernelMessagesWindow::KernelMessagesWindow(QWidget *parent) :
 KernelMessagesWindow::~KernelMessagesWindow()
 {
     delete ui;
-    system("rm /home/user/.tempdmesg 2> /dev/null");
+    system("rm /root/.tempdmesg 2> /dev/null");
 }
 
 void KernelMessagesWindow::showLogs()
