@@ -2,6 +2,7 @@
 #define MAINWINDOW_H
 #include <kernelmessageswindow.h>
 #include <helpwindow.h>
+//#include <settingswindow.h>
 #include <QMainWindow>
 #include <aboutwindow.h>
 #include <QDebug>
@@ -14,6 +15,8 @@
 #include <QMaemo5InformationBox>
 #endif
 
+#define API "20101110"
+
 namespace Ui {
     class MainWindow;
 }
@@ -40,11 +43,13 @@ private slots:
     void vbusOn();
     void vbusOff();
     void kernelmessages();
+  //  void settingsWindow();
     void orientationChanged();
     void enumerate();
     void helpWindow();
     void mount();
     void unmount();
+    void overrideKernelVersion();
 };
 
 #endif // MAINWINDOW_H
